@@ -207,6 +207,31 @@ pub mod govern {
 
         Ok(())
     }
+
+    /// Creates a [ProposalMeta].
+    #[access_control(ctx.accounts.validate())]
+    pub fn create_proposal_meta(
+        ctx: Context<CreateProposalMeta>,
+        _bump: u8,
+        title: String,
+        description_link: String,
+    ) -> ProgramResult {
+        msg!("Instruction: create_proposal_meta");
+
+        let proposal_meta = &mut ctx.accounts.proposal_meta;
+        proposal_meta.proposal = ctx.accounts.proposal.key();
+        proposal_meta.title = title.clone();
+        proposal_meta.description_link = description_link.clone();
+
+        emit!(ProposalMetaCreateEvent {
+            governor: ctx.accounts.proposal.governor.key(),
+            proposal: ctx.accounts.proposal.key(),
+            title,
+            description_link,
+        });
+
+        Ok(())
+    }
 }
 
 /// Errors.
